if(!self.define){let e,n={};const i=(i,r)=>(i=new URL(i+".js",r).href,n[i]||new Promise(n=>{if("document"in self){const e=document.createElement("script");e.src=i,e.onload=n,document.head.appendChild(e)}else e=i,importScripts(i),n()}).then(()=>{let e=n[i];if(!e)throw new Error(`Module ${i} didn’t register its module`);return e}));self.define=(r,a)=>{const s=e||("document"in self?document.currentScript.src:"")||location.href;if(n[s])return;let l={};const o=e=>i(e,s),c={module:{uri:s},exports:l,require:o};n[s]=Promise.all(r.map(e=>c[e]||o(e))).then(e=>(a(...e),l))}}define(["./workbox-3e722498"],function(e){"use strict";self.skipWaiting(),e.clientsClaim(),e.precacheAndRoute([{url:"logo.png",revision:"7314384b59598d0528d2f6bd911f5f90"},{url:"index.html",revision:"1f0afac7b2b29c4f673b8e2b58a348ed"},{url:"icon.png",revision:"7ad8d150424db3a152c232e87ba0145b"},{url:"app-64x64.png",revision:"71b6ebdae41ab885d77a1a9e9377367c"},{url:"app-512x512.png",revision:"1122a768f0a15d689c203fddce2ea581"},{url:"app-192x192.png",revision:"022da84284bcaec81b60c066832bac35"},{url:"app-180x180.png",revision:"1adc541193af9556bc20868d0c65424f"},{url:"app-152x152.png",revision:"b17ac0d24bce2a865c09c2ac61ecda5b"},{url:"app-144x144.png",revision:"c6ffafa0672d8e12935097a6a124ab0c"},{url:"app-120x120.png",revision:"894d6de89ec557d51ea5f25028e78b3d"},{url:"assets/workbox-window.prod.es5-vqzQaGvo.js",revision:null},{url:"assets/jetbrains-mono-latin-ext-400-normal-Bc8Ftmh3.woff2",revision:null},{url:"assets/jetbrains-mono-latin-400-normal-V6pRDFza.woff2",revision:null},{url:"assets/jetbrains-mono-greek-400-normal-C190GLew.woff2",revision:null},{url:"assets/jetbrains-mono-cyrillic-400-normal-BEIGL1Tu.woff2",revision:null},{url:"assets/inter-vietnamese-400-normal-DMkecbls.woff2",revision:null},{url:"assets/inter-latin-ext-400-normal-C1nco2VV.woff2",revision:null},{url:"assets/inter-latin-400-normal-C38fXH4l.woff2",revision:null},{url:"assets/inter-greek-ext-400-normal-DGGRlc-M.woff2",revision:null},{url:"assets/inter-greek-400-normal-B4URO6DV.woff2",revision:null},{url:"assets/inter-cyrillic-ext-400-normal-BQZuk6qB.woff2",revision:null},{url:"assets/inter-cyrillic-400-normal-obahsSVq.woff2",revision:null},{url:"assets/index-Dz-CDzM6.css",revision:null},{url:"assets/index-CNlEjL40.js",revision:null},{url:"app-120x120.png",revision:"894d6de89ec557d51ea5f25028e78b3d"},{url:"app-144x144.png",revision:"c6ffafa0672d8e12935097a6a124ab0c"},{url:"app-152x152.png",revision:"b17ac0d24bce2a865c09c2ac61ecda5b"},{url:"app-180x180.png",revision:"1adc541193af9556bc20868d0c65424f"},{url:"app-192x192.png",revision:"022da84284bcaec81b60c066832bac35"},{url:"app-512x512.png",revision:"1122a768f0a15d689c203fddce2ea581"},{url:"app-64x64.png",revision:"71b6ebdae41ab885d77a1a9e9377367c"},{url:"icon.png",revision:"7ad8d150424db3a152c232e87ba0145b"},{url:"logo.png",revision:"7314384b59598d0528d2f6bd911f5f90"},{url:"manifest.webmanifest",revision:"b11bcf41601567bff813a4fa248b902a"}],{}),e.cleanupOutdatedCaches(),e.registerRoute(new e.NavigationRoute(e.createHandlerBoundToURL("index.html"),{denylist:[/^\/api\//]})),e.registerRoute(/^\/api\//,new e.NetworkOnly,"GET")});
